retry: wrap a function so that it keeps executing until none of the...

Description Usage Arguments

Description

wrap a function so that it keeps executing until none of the specified errors is returned, probably most useful for functions that try to use the network

Usage

1
2
retry(.f, errors = getOption("retry_errors",
  "Error in the HTTP2 framing layer"), max_tries = 10)

Arguments

.f

function to be wrapped

errors

vector of error messages on whose return we should retry

max_tries

maximum number of retries


mlgrm/retryr documentation built on May 12, 2019, 5:17 p.m.