wrap a function so that it keeps executing until none of the specified errors is returned, probably most useful for functions that try to use the network
1 2 |
.f |
function to be wrapped |
errors |
vector of error messages on whose return we should retry |
max_tries |
maximum number of retries |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.